@@ -1,7 +1,7 @@
 /*
  * This file is part of Soprano Project.
  *
- * Copyright (C) 2007 Sebastian Trueg <trueg@kde.org>
+ * Copyright (C) 2007-2008 Sebastian Trueg <trueg@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -681,7 +681,7 @@ bool Soprano::Client::ClientConnection::checkProtocolVersion()
 
 bool Soprano::Client::ClientConnection::testConnection()
 {
-    return socket() != 0;
+    return isConnected( socket() );
 }
 
 #include "clientconnection.moc"
